@@ -13,7 +13,7 @@ import libmd
 import cat as cat
 import json_to_obs as jo
 
-__version__ = 'v1.3.8'
+__version__ = 'v1.3.9'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind, \
@@ -469,12 +469,15 @@ class TranslateJson(object):
             os.system("mv " + svg_name + " " + self.gitbookpath)
             #register_data += '\n<br>\n'
             register_data += '\n'
-            file_path = os.path.join(self.gitbookpath, name + '.md')
+            self.reg_data += register_data + '\n'
             self.reg_rst += '   ' + name + '.md\n'
+
+            file_path = os.path.join(self.gitbookpath, name + '.md')
             with open(file_path, 'w') as fd:
                 fd.write(register_data)
-            #self.reg_data += '{% include "./' + name +  '.md" %}\n'
-            self.reg_data += register_data + '\n'
+                for i in range(fields_len):
+                    f = fields[i]
+                    fd.write('\n' + '### ' + f['name'])
 
     def add_xmind_md(self, name, des):
         self.xmind_md += '* ' + name + '\n'
@@ -738,11 +741,11 @@ def main():
             save_dir)
     tj.main()
 
-    tjo = jo.TranslateJson(js_file, link_path, dir_type, output_md, output_gitbook, \
-            output_xmind,save_dir)
-    tjo.main()
-    
-    cat.cat_md(link_path, tj.file_msg)
+    #tjo = jo.TranslateJson(js_file, link_path, dir_type, output_md, output_gitbook, \
+    #        output_xmind,save_dir)
+    #tjo.main()
+    #
+    #cat.cat_md(link_path, tj.file_msg)
 
 if __name__ == "__main__":
     main()
